from glyles import convert


# print(convert("8SGlc"))
# print(convert("2dDig"))
# print(convert("2BzDig"))
# print(convert("Man(a1-2)Dig"))
# print(convert("Gal(a1-2)[Man(b1-2)]Tal"))
# print(convert("Man(a1-2)Gal"))
# print(convert("Man(a1-8)Gal"))
# print(convert("Man(a8-2)Gal"))
# print(convert("Man(a8-8)Gal"))
print(convert("3Br3BrMan"))
